import React from 'react';
import * as Yup from 'yup';
import { useFormik, Form, FormikProvider } from 'formik';
import { Modal } from 'react-bootstrap'

import {  
    Box, Button,
    Stack, TextField, 
    InputLabel,MenuItem,FormControl,Select
} from '@mui/material';



export default function Manual ( props ) {

    const NewPlazaSchema = Yup.object().shape({
        nombrepuesto : Yup.string().required('El nombre es requerido').min(5).max(100),
        puestosuperior : Yup.number("El puesto superior debe ser un numero"),
        areadepto : Yup.number().required('Escoge alguna area'),
        fecha : Yup.date("Ingresa una fecha válida").required('Ingresa una fecha válida'),
        notas : Yup.string().required('Ingresa una fecha válida'),
    })

    let { visible, onClose, success } = props

    const formik = useFormik({
        initialValues: {
            nombrepuesto: "",
            puestosuperior: "",
            areadepto: "",
            fecha: "",
            notas: "",
        },
        onSubmit: (fields) => {
            console.log(fields)
        },
        validationSchema: NewPlazaSchema,
    });

    const { errors, touched, handleSubmit, getFieldProps } = formik;

    return (

        <Modal size="lg" aria-labelledby="contained-modal-title-vcenter" centered  show={visible} onHide={onClose}>
            <Modal.Header>
                <button onClick={onClose}  type="button" className="close" data-dismiss="modal">&times;</button>
                <h4 className="modal-title" style={{color : '#252525'}}>Agregar plaza</h4>
            </Modal.Header>
            <Modal.Body className="modal-body">

                <FormikProvider style={{ padding : 25 }} value={formik}>
                    <Form autoComplete="off" noValidate onSubmit={handleSubmit}>
                        <Stack spacing={3}>
                            <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>

                                <TextField
                                    label="Nombre: "
                                    fullWidth
                                    {...getFieldProps('nombrepuesto')}
                                    error={Boolean(touched.nombrepuesto && errors.nombrepuesto)}
                                    helperText={touched.nombrepuesto && errors.nombrepuesto}
                                />

                                <TextField
                                    label="Puesto Superior: "
                                    fullWidth
                                    {...getFieldProps('puestosuperior')}
                                    error={Boolean(touched.puestosuperior && errors.puestosuperior)}
                                    helperText={touched.puestosuperior && errors.puestosuperior}
                                />

                            </Stack>
                            <Stack direction={{ xs: 'column', sm: 'row' }} spacing={2}>
                                <TextField
                                    label="Departamento"
                                    fullWidth
                                    type="text"
                                    {...getFieldProps('puestosuperior')}
                                    error={Boolean(touched.areadepto && errors.areadepto)}
                                    helperText={touched.areadepto && errors.areadepto}
                                />
                                <TextField
                                    label="Fecha Creacion"
                                    fullWidth
                                    type="text"
                                    {...getFieldProps('fecha')}
                                    error={Boolean(touched.fecha && errors.fecha)}
                                    helperText={touched.fecha && errors.fecha}
                                />
                            </Stack>
                            <Stack direction={{ xs: 'column', sm: 'row' }} spacing={1}>
                                <TextField
                                    id="filled-multiline-static"
                                    multiline
                                    rows={4}
                                    defaultValue="Default Value"
                                    variant="filled"
                                    label="notas"
                                    fullWidth
                                    type="text"
                                    {...getFieldProps('notas')}
                                    error={Boolean(touched.notas && errors.notas)}
                                    helperText={touched.notas && errors.notas}
                                />
                            </Stack>
                        </Stack>
                    </Form>
                </FormikProvider>

                <Modal.Footer>OK</Modal.Footer>

            </Modal.Body>
        </Modal>
    )
}
